@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------
-# Copyright (c) 2009  Jendrik Seipp
+# Copyright (c) 2008-2024 Jendrik Seipp
 #
 # RedNotebook is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -67,3 +67,6 @@ if WebKit2:
                     self.highlight(self.search_text)
                 else:
                     webview.get_find_controller().search_finish()
+
+        def copy_to_clipboard(self):
+            self.execute_editing_command(WebKit2.EDITING_COMMAND_COPY)
